@@ -15,10 +15,10 @@ port="8080"
 cube_upload_param={}
 # conn_det=None
 chg_log_from_date = "2023-01-14"
-chg_log_to_date = "2023-01-18"
-short_cut_proj_id = "AF09B3E3458F78B4FBE4DEB68528BF7B" #E
-short_cut_folder_id = "14F4C84040446BAD5E37D8A5A2D6F6BC"
-migration_folder_id = "8BF21A4D49345DF8E673DA8151E11932"
+chg_log_to_date = "2023-01-22"
+short_cut_proj_id = "B19DEDCC11D4E0EFC000EB9495D0F44F" #E
+short_cut_folder_id = "E9E592074122ADC61CF2AFA10941EFBD"
+migration_folder_id = "E586B4F645D1C3ADC066A2B93804FF0A"
 mtdi_id = ""  # "E37952C94F2195BF15BF6B953C84AD58"
 
 chg_log_rep_proj_id = "B19DEDCC11D4E0EFC000EB9495D0F44F"
@@ -52,8 +52,8 @@ change_query={"chg_log_from_date":chg_log_from_date
               ,"cube_name":"TestCube"}
 
 
-
-conn=mig.login(base_url=base_url,username=username,password=password,project_id="B19DEDCC11D4E0EFC000EB9495D0F44F")
+conn=mig.login(base_url=base_url,username=username,password=password,project_id=chg_log_rep_proj_id)
+""" 
 res=mig_rep.chk_chg_log_cols(conn=conn,report_id="454B29DF4872B9C74785A5A0A1A5FFB0")
 print(res)
 
@@ -96,9 +96,9 @@ cube_upload_param["migration_folder_id"]=change_log_report["migration_folder_id"
 cube_upload_param["mtdi_id"]=None
 
 cube_it.up_load_to_cube(conn=conn,cube_upload_param=cube_upload_param)
-
+"""
 #
-obj_id_l=['335FFA9640B5F1C1E0C0F3A469E627A8;55','59D59D7741F61B68480572B9B7A05709;4'] #Dossier & metric "hire date"
+obj_id_l=['335FFA9640B5F1C1E0C0F3A469E627A8;55','59D59D7741F61B68480572B9B7A05709;4','C6B60AF341D38FF8DC6F3AA8D11D3115;55'] #Dossier & metric "hire date"
 used_obj_dict_l=mig_search.used_by_obj_l_rec(conn=conn,project_id=change_log_report["chg_log_rep_proj_id"]
                           ,obj_id_l=obj_id_l)
 #export search result to cube
