@@ -1,17 +1,17 @@
 from mstrio.connection import Connection
-from mstrio.connection import get_connection
+#from mstrio.connection import get_connection
+#from mstrio.api import projects
+#from mstrio.project_objects import report
+# import error_controller
+# from mstrio.utils.error_handlers import ErrorHandler
 from mstrio.utils import parser
 from mstrio.project_objects.datasets import SuperCube
 from mstrio.api import reports
-from mstrio.api import projects
 from mstrio.api import browsing
 from mstrio.api import objects as api_obj
-from mstrio.project_objects import report
 from mstrio.object_management import object
 from mstrio.object_management import folder
 import pandas as pd
-# import error_controller
-# from mstrio.utils.error_handlers import ErrorHandler
 from typing import Optional
 from mstr_robotics.helper import str_func
 from mstr_robotics.logger import logger
@@ -38,18 +38,19 @@ class rep:
 
     @log(err_name="Failed to open change log report")
     def open_Instance(self, conn, project_id, report_id):
-        # conn.headers["X-MSTR-ProjectID"] = project_id
+        conn.headers["X-MSTR-ProjectID"] = project_id
         rep_instance = self.i_reports.report_instance(connection=conn, report_id=report_id)
         return rep_instance.json()["instanceId"]
 
     @log(err_name="Faile to set prompt answers for change log report")
-    def set_inst_prompt_ans(self, conn, project_id, report_id, instance_id, prompt_answ):
+    def set_inst_prompt_ans(self, conn, report_id, instance_id, prompt_answ):
         prompt_answ_url = f'{conn.base_url}/api/reports/{report_id}/instances/{instance_id}/prompts/answers'
         ret_prompt_ans = conn.put(prompt_answ_url, data=prompt_answ)
         return ret_prompt_ans
 
     @log(err_name="Failed to execute or export change log report")
-    def report_dict(self, conn, project_id, report_id, instance_id):
+    def report_dict(self, conn, report_id, instance_id):
+        #conn.headers["X-MSTR-ProjectID"] = project_id
         report_ds = self.i_reports.report_instance_id(connection=conn, report_id=report_id, instance_id=instance_id)
         s = conn.get(f'{conn.base_url}/api/v2/reports/{report_id}/instances/{instance_id}/sqlView')
         print(s.json())
@@ -93,8 +94,9 @@ class mstr_global:
         return existing_obj_l
 
     @log(err_name="Failed to rename object")
-    def _rename_object(self, object, new_name, desc_str):
-        object.alter(name=new_name, description=desc_str)
+    def _rename_object(self, conn,project_id,object_id,object_type, new_name, desc_str):
+        short_cut_obj = object.Object(connection=conn, type=object_type, id=object_id)
+        short_cut_obj.alter(name=str(new_name), description=str(desc_str))
         return
 
     @log(err_name="Didn't find object or could parse it")
@@ -104,12 +106,7 @@ class mstr_global:
                                               object_type=type,
                                               project_id=project_id)
 
-    @log(err_name="No idea here. Pls. Check the error yourself :-)")
-    def get_short_cut_obj(self, conn, project_id, object_id, type):
-        short_cut_obj = object.Object(connection=conn, type=type, id=object_id)
-        return short_cut_obj
-
-    @log(err_name="Could delete object")
+    @log(err_name="Could not delete object")
     def _delete_object(self, conn, project_id, existing_obj_l):
         self.set_project_id(conn=conn, project_id=project_id)
         for o in existing_obj_l:
@@ -137,11 +134,15 @@ class mstr_global:
     @log(err_name="Project not found")
     def get_project_name(self, conn, project_id):
         project_resp = conn.get(f'{conn.base_url}/api/projects')
+        project_name=""
         for p in project_resp.json():
             if p["id"] == project_id:
-                return p["name"]
-            else:
-                raise
+                project_name= p["name"]
+
+        if project_name!="":
+            return project_name
+        else:
+            raise
 
     def bld_df_from_search_result(self, conn, search_l):
         full_obj_info_l = []
@@ -195,10 +196,10 @@ class mstr_global:
             , "subtype": str(obj_d.get('subtype'))
             , "owner_id": str(obj_d["owner"].get('id'))
             , "owner_name": str(obj_d["owner"].get('name'))
-            , "date_modified": str(obj_d["owner"].get('dateModified'))
-            , "date_created": str(obj_d["owner"].get('dateCreated'))
+            , "date_modified": str(obj_d["dateModified"])
+            , "date_created": str(obj_d["dateCreated"])
                      }
-        # print("project: " + proj_g + "object: " + str(obj_d.get('id')) )
+        print(obj_row_d["date_created"] )
         return obj_row_d
 
     def bld_mstr_obj_guid(self, obj_md_id=None):
